/* $Id: LuceneTask.java 152682 2005-02-08 18:13:39Z gregor $  */

package org.apache.lenya.cms.task;

import org.apache.avalon.framework.parameters.ParameterException;
import org.apache.log4j.Logger;

import java.io.File;

import org.apache.lenya.lucene.index.Index;
import org.apache.lenya.lucene.index.Indexer;

/**
 * Lucene Task
 */
public class LuceneTask extends AbstractTask {
    private static final Logger log = Logger.getLogger(LuceneTask.class);

    /**
     * @see org.apache.lenya.cms.task.Task#execute(java.lang.String)
     */
    public void execute(String servletContextPath) throws ExecutionException {
        Indexer indexer;
        String files;
        try {
            //outputParameters();

            log.debug("Servlet context path: " + servletContextPath);

            String publicationId = getParameters().getParameter("publication-id");
            log.debug("Publication ID: " + publicationId);

            files = getParameters().getParameter("properties.files2index");
            log.debug("Files 2 index: " + files);

            String luceneConfig = getParameters().getParameter("config");
            log.debug("Lucene configuration: " + luceneConfig);

            String luceneConfigAbsolutePath = servletContextPath + File.separator + "lenya" + File.separator + "pubs" + File.separator + publicationId  + File.separator + luceneConfig;
            log.debug("Lucene configuration: " + luceneConfigAbsolutePath);

            indexer = Index.getIndexer(luceneConfigAbsolutePath);
    	    indexer.indexDocument(new File(files));
        } catch (final ParameterException e) {
            log.error("" +e.toString());
            throw new ExecutionException(e);
        } catch (Exception e) {
            log.error("" +e.toString());
            throw new ExecutionException(e);
        }
    }

    /**
     * Output parameters for debugging
     * @throws Exception if an error occurs
     * FIXME don't throw Exception here
     */
    public void outputParameters() throws Exception {
        String[] names = getParameters().getNames();
        for (int i = 0; i < names.length; i++) {
            log.error("Name: " + names[i]);
            log.error("Value: " + getParameters().getParameter(names[i]));
        }
    }
}
