/*
 * Copyright  1999-2005 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.lenya.transaction;

/**
 * Identity map.
 * 
 * @version $Id: IdentityMap.java 179568 2005-06-02 09:27:26Z jwkaltz $
 */
public interface IdentityMap {

    /**
     * Retrieve an instance from the map. If no instance exists
     * for the given key, the factory is used to build one.
     * @see #getFactory(java.lang.String)
     * @param type The type of the transactionable.
     * @param key The key for the transactionable.
     * @return A transactionable.
     */
    Identifiable get(String type, String key);

    /**
     * Sets the factory.
     * @param type The transactionable type to use the factory for.
     * @param factory The factory to use.
     */
    void setFactory(String type, IdentifiableFactory factory);

    /**
     * @param type The type to return the factory for.
     * @return The factory.
     */
    IdentifiableFactory getFactory(String type);

    /**
     * Returns the unit of work. This maybe <code>null</code> if the identity map is not involved
     * in a transaction.
     * @return The unit of work.
     */
    UnitOfWork getUnitOfWork();

    /**
     * @param unit The unit of work to use.
     */
    void setUnitOfWork(UnitOfWork unit);
    
    /**
     * @return All objects in this map.
     */
    Identifiable[] getObjects();

}
