/*
 * Copyright  1999-2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.lenya.workflow;

/**
 * Interface for objects which can be workflowed.
 *
 * @version $Id: Workflowable.java 179790 2005-06-03 13:45:13Z andreas $
 */
public interface Workflowable {

    /**
     * @return The versions in chronological order.
     */
    Version[] getVersions();
    
    /**
     * @return The latest version.
     */
    Version getLatestVersion();
    
    /**
     * Adds a new version.
     * @param workflow The workflow.
     * @param version The version.
     * @param situation The situation in which the version was added.
     */
    void newVersion(Workflow workflow, Version version, Situation situation);
    
    /**
     * @return The URI to resolve the schema configuration from.
     */
    String getWorkflowSchemaURI();
    
}
